@@ -16,23 +16,23 @@
 
 import logging as log
 import os
-import signal
 import sys
 from textwrap import dedent
 
 from hspylib.core.enums.charset import Charset
-from hspylib.modules.application.exit_status import ExitStatus
-from hspylib.core.tools.commons import syserr
+from hspylib.core.tools.commons import syserr, hook_exit_signals
 from hspylib.core.zoned_datetime import now
+from hspylib.modules.application.exit_status import ExitStatus
 from hspylib.modules.application.version import Version
-from hspylib.modules.cli.cli_application import CliApplication
+from hspylib.modules.cli.tui.tui_application import TUIApplication
+
 from vault.__classpath__ import _Classpath
 from vault.core.vault import Vault
 from vault.core.vault_config import VaultConfig
 from vault.exception.exceptions import VaultOpenError
 
 
-class Main(CliApplication):
+class Main(TUIApplication):
     """HSPyLib Vault - Manage your secrets"""
 
     # The welcome message
@@ -50,7 +50,7 @@ class Main(CliApplication):
         self.vault = Vault(self.RESOURCE_DIR)
 
     def _setup_arguments(self) -> None:
-        # @formatter:off
+        # fmt: off
         self._with_chained_args('operation', 'the Vault operation to process') \
             .argument('list', 'list all entries matching the given filter criteria, if specified') \
                 .add_parameter('filter', "filter the listed vault entries by it's name", nargs='*') \
@@ -65,12 +65,14 @@ class Main(CliApplication):
             .argument('upd', 'update an existing vault entry') \
                 .add_parameter('name', 'the name of the vault entry which identifies it') \
                 .add_parameter('hint', 'applicable hints related to that vault entry') \
-                .add_parameter('password', 'the password of the entry. If not provided, it will be prompted', nargs='?') \
-        # @formatter:on
+                .add_parameter('password', 'the password of the entry. If not provided, it will be prompted',
+                               nargs='?')  # fmt: on
 
     def _main(self, *params, **kwargs) -> ExitStatus:
         """Run the application with the command line arguments"""
-        log.info(dedent(f'''
+        log.info(
+            dedent(
+                f"""
         {self._app_name} v{self._app_version}
 
         Settings ==============================
@@ -78,12 +80,11 @@ class Main(CliApplication):
                 VAULT_FILE: {VaultConfig.INSTANCE.vault_file}
                 STARTED: {now("%Y-%m-%d %H:%M:%S")}
         =======================================\n
-        '''))
+        """
+            )
+        )
 
-        signal.signal(signal.SIGINT, self._abort)
-        signal.signal(signal.SIGTERM, self._abort)
-        signal.signal(signal.SIGABRT, self._abort)
-        signal.signal(signal.SIGHUP, self._abort)
+        hook_exit_signals(self._abort)
 
         return self._exec_application()
 
@@ -99,25 +100,25 @@ class Main(CliApplication):
         self._cleanup()
         self.exit(signum, frame)
 
-    def _exec_application(self, ) -> ExitStatus:
+    def _exec_application(self) -> ExitStatus:
         """Execute the specified vault operation"""
-        ret_val, op = 0, self.get_arg('operation')
+        ret_val, op = 0, self.get_arg("operation")
         with self.vault.open() as unlocked:
             if not unlocked:
                 raise VaultOpenError("Unable to open/unlock vault")
-            if op == 'add':
-                self.vault.add(self.get_arg('name'), self.get_arg('hint'), self.get_arg('password'))
-            elif op == 'get':
-                self.vault.get(self.get_arg('name'))
-            elif op == 'del':
-                self.vault.remove(self.get_arg('name'))
-            elif op == 'upd':
-                self.vault.update(self.get_arg('name'), self.get_arg('hint'), self.get_arg('password'))
-            elif op == 'list':
-                self.vault.list(self.get_arg('filter'))
+            if op == "add":
+                self.vault.add(self.get_arg("name"), self.get_arg("hint"), self.get_arg("password"))
+            elif op == "get":
+                self.vault.get(self.get_arg("name"))
+            elif op == "del":
+                self.vault.remove(self.get_arg("name"))
+            elif op == "upd":
+                self.vault.update(self.get_arg("name"), self.get_arg("hint"), self.get_arg("password"))
+            elif op == "list":
+                self.vault.list(self.get_arg("filter"))
             else:
                 ret_val = 1
-                syserr(f'### Invalid operation: {op}')
+                syserr(f"### Invalid operation: {op}")
                 self.usage(ExitStatus.FAILED)
 
         return ExitStatus.of(ret_val)
@@ -125,4 +126,4 @@ class Main(CliApplication):
 
 if __name__ == "__main__":
     # Application entry point
-    Main('vault').INSTANCE.run(sys.argv[1:])
+    Main("vault").INSTANCE.run(sys.argv[1:])
